==> jumbo-pbx-0.1.tar.gz: jumbo-pbx-0.1/pbx/reports/admin.py <==
# -*- coding: utf-8 -*-
'''
Created on 02/ago/2011

@author: simone cittadini
'''
from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from jumbo.admin.options import ExtendibleModelAdmin
from jumbo.middleware.thread_local import get_current_user
from jumbo.utils.functions import get_settings

from models import Cdr

#DOWNLOAD_USERNAME = get_settings('reports.settings', 'DOWNLOAD_USERNAME')


class CdrSearchForm(forms.ModelForm):
    class Meta:
        model = Cdr
        display_fields = (
            'src__startswith', 'dst__startswith',
        )

    def __init__(self, *args, **kws):
        super(CdrSearchForm, self).__init__(*args, **kws)
        self.fields['src__startswith'] = forms.CharField(label=_("src"), required=False)
        self.fields['dst__startswith'] = forms.CharField(label=_("dst"), required=False)

        
class CdrAdmin(ExtendibleModelAdmin):
    list_display = ('calldate',
                    'clid',
                    'channel',
                    'realsrc',
                    'src',
                    'dst',
                    'billsec',
                    'disposition',
                    'get_recorded_file',
#                    'get_edit_icon',
                    )
    
    def get_recorded_file(self, obj):
        u = get_current_user()
        if u.username:# == DOWNLOAD_USERNAME:
            if obj.recorded_file and obj.billsec > 0:
                return "<a href='/files/monitor/%s.wav' target='_blank'><img src='/static/admin/images/url_icon.png' /></a>" % (obj.recorded_file,)
            else:
                return ""
        else:
            if obj.recorded_file and obj.billsec > 0:
                return "<img src='/static/admin/images/url_icon.png' />"
            else:
                return ""
    get_recorded_file.allow_tags = True
    get_recorded_file.short_description = 'rec'
    
    search_form = CdrSearchForm

admin.site.register(Cdr, CdrAdmin)

==> jumbo-pbx-0.1.1.tar.gz: jumbo-pbx-0.1.1/pbx/reports/admin.py <==
# -*- coding: utf-8 -*-
'''
Created on 02/ago/2011

@author: simone cittadini
'''
from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _

from jumbo.admin.options import ExtendibleModelAdmin
from jumbo.middleware.thread_local import get_current_user
from jumbo.utils.functions import get_settings

from models import Cdr

# usato solo da anima ma utile, lasciamo in vista di integrazione
#DONWLOAD_USERNAME = get_settings('reports.settings', 'DONWLOAD_USERNAME')


class CdrSearchForm(forms.ModelForm):
    class Meta:
        model = Cdr
        display_fields = (
            'src__startswith', 'dst__startswith', 'calldate__gte', 'calldate__lte'
        )

    def __init__(self, *args, **kws):
        super(CdrSearchForm, self).__init__(*args, **kws)
        self.fields['src__startswith'] = forms.CharField(label=_("src"), required=False)
        self.fields['dst__startswith'] = forms.CharField(label=_("dst"), required=False)
        self.fields['calldate__gte'] = forms.CharField(label=_("dal"), required=False)
        self.fields['calldate__lte'] = forms.CharField(label=_("al"), required=False)

        
class CdrAdmin(ExtendibleModelAdmin):
    list_display = ('calldate',
                    'clid',
                    'channel',
                    'realsrc',
                    'src',
                    'dst',
                    'billsec',
                    'disposition',
                    'get_recorded_file',
#                    'get_edit_icon',
                    )
    
    def get_recorded_file(self, obj):
        u = get_current_user()
        if u.username:# == DOWNLOAD_USERNAME:
            if obj.recorded_file and obj.billsec > 0:
                return "<a href='/files/monitor/%s.wav' target='_blank'><img src='/static/admin/images/url_icon.png' /></a>" % (obj.recorded_file,)
            else:
                return ""
        else:
            if obj.recorded_file and obj.billsec > 0:
                return "<img src='/static/admin/images/url_icon.png' />"
            else:
                return ""
    get_recorded_file.allow_tags = True
    get_recorded_file.short_description = 'rec'
    
    search_form = CdrSearchForm

admin.site.register(Cdr, CdrAdmin)
